package ru.mousecray.plants.blocks;

import net.minecraft.util.math.AxisAlignedBB;
import net.minecraft.block.state.IBlockState;
import net.minecraftforge.common.ForgeHooks;
import ru.mousecray.plants.items.ListItems;
import net.minecraft.util.math.BlockPos;
import net.minecraft.world.IBlockAccess;
import net.minecraft.block.BlockCrops;
import net.minecraft.util.NonNullList;
import net.minecraft.item.ItemStack;
import net.minecraft.world.World;
import net.minecraft.init.Blocks;
import net.minecraft.init.Items;
import net.minecraft.item.Item;

import java.util.Random;

public class CaveCrops extends BlockCrops {
    //    ,    .    , 
    //    ,   .
	
	//  BoundingBox',     .
    private static final AxisAlignedBB[] CAVE_CROPS_AABB = new AxisAlignedBB[] {new AxisAlignedBB(0.0D, 0.0D, 0.0D, 1.0D, 0.125D, 1.0D), new AxisAlignedBB(0.0D, 0.0D, 0.0D, 1.0D, 0.1875D, 1.0D), new AxisAlignedBB(0.0D, 0.0D, 0.0D, 1.0D, 0.25D, 1.0D), new AxisAlignedBB(0.0D, 0.0D, 0.0D, 1.0D, 0.3125D, 1.0D), new AxisAlignedBB(0.0D, 0.0D, 0.0D, 1.0D, 0.375D, 1.0D), new AxisAlignedBB(0.0D, 0.0D, 0.0D, 1.0D, 0.4375D, 1.0D), new AxisAlignedBB(0.0D, 0.0D, 0.0D, 1.0D, 0.5D, 1.0D), new AxisAlignedBB(0.0D, 0.0D, 0.0D, 1.0D, 0.5625D, 1.0D)};

    public CaveCrops() {
        setUnlocalizedName("cave_crops");
        setRegistryName("cave_crops");
        setLightLevel(0.3F);
        //  ,   BlockCrops,    
    }

    @Override
    //    
    public boolean canPlaceBlockAt(World world, BlockPos pos) {
        return world.getBlockState(pos).getBlock().isReplaceable(world, pos) && world.getBlockState(pos.down()).getBlock() == Blocks.COBBLESTONE;
    }

    @Override
    //,  ,     ,  
    //  : "    ". ,   
    public boolean canBlockStay(World world, BlockPos pos, IBlockState state) {
        return world.getBlockState(pos.down()).getBlock() == Blocks.COBBLESTONE;
    }

    @Override
    // .   . .    
    protected Item getSeed() {
        return ListItems.CAVE_SEEDS;
    }

    @Override
    // , 
    protected Item getCrop() {
        return Items.COAL;
    }

    @Override
    // BoundigBox,    
    public AxisAlignedBB getBoundingBox(IBlockState state, IBlockAccess source, BlockPos pos) {
        return CAVE_CROPS_AABB[((Integer)state.getValue(getAgeProperty())).intValue()];
    }

    @Override
    /*
     *     ,  .
     * ,  ,   - 30%
     *  10%
     */
    public void getDrops(NonNullList<ItemStack> drops, IBlockAccess world, BlockPos pos, IBlockState state, int fortune) {
        super.getDrops(drops, world, pos, state, fortune);
        //,  ,  ,  
        if(this.isMaxAge(state)) {
            int random = RANDOM.nextInt(100)+1;

            if (random < 30) {
                drops.add(new ItemStack(Items.DYE, 1, 4));
            }
            else if(random < 60) {
                drops.add(new ItemStack(Items.GOLD_NUGGET));
            }
            if(random < 90) {
                drops.add(new ItemStack(Items.IRON_NUGGET));
            }
            else {
                drops.add(new ItemStack(Items.DIAMOND));
            }
        }
    }

    @Override
    //    ,     
    // .     ,   , 
    //    ,  ,      .
    public void updateTick(World world, BlockPos pos, IBlockState state, Random rand) {
    	//,       ( )
    	//   ,     canBlockStay, 
    	//   
        this.checkAndDropBlock(world, pos, state);
        
        // "" 
        int i = this.getAge(state);       
        //  .
        float f = getGrowthChance(this, world, pos);
		
	if(world.getLightFromNeighbors(pos.up()) <= 5) {
		//,     
		if (i < this.getMaxAge()) {
		//   .    .
			if(ForgeHooks.onCropsGrowPre(world, pos, state, rand.nextInt((int)(25.0F / f) + 1) == 0)) {
				//   ,    1
				world.setBlockState(pos, this.withAge(i + 1), 2);
				//  .      , 
				//     ,    , 
				//    
				ForgeHooks.onCropsGrowPost(world, pos, state, world.getBlockState(pos));
			}
		}
	}
	//     5, 
	//,      0,   
	else if(i != 0) {
		//   ,    1,
		//-   
		world.setBlockState(pos, this.withAge(i - 1), 2);
		//  .
		ForgeHooks.onCropsGrowPost(world, pos, state, world.getBlockState(pos));
	}
	//     ,    , 
	else {
		//  , -    ()
		world.setBlockToAir(pos);
		//  .
		ForgeHooks.onCropsGrowPost(world, pos, state, world.getBlockState(pos));
	}
    }
}